**Simple Wiki** - это вики движок, отображающий файловую структуру в веб-энциклопедию; поддерживает статьи в форматах .html, .md. Simple Wiki написана на языке python, поддерживает гибкое расширение и стилизацию.
